@@ -36,8 +36,8 @@ class Status:
                     inifile = linuxcnc.ini(self.framework.machine.info["ini_filename"])
                     user_data = {
                         "user": self.framework.machine.user,
-                        "increments": inifile.find("DISPLAY", "INCREMENTS") or [],
-                        "coordinates": inifile.find("TRAJ", "COORDINATES") or "unknown",
+                        "increments": list(inifile.find("DISPLAY", "INCREMENTS")) or [],
+                        "coordinates": list(inifile.find("TRAJ", "COORDINATES")) or [],
                         "linear_units": inifile.find("TRAJ", "LINEAR_UNITS") or "mm",
                         "angular_units": inifile.find("TRAJ", "ANGULAR_UNITS") or "degree",
                         "estop": self.framework.machine.info["estop"],
@@ -50,10 +50,8 @@ class Status:
                     }
                     self.framework.machine.info["user_data"] = user_data
 
+                    self.framework.machine.axis = user_data["coordinates"]
+
                     self.framework.utils.service.service_write({"command": "launch:machine:info", "message": "", "data": self.framework.machine.info})
             self.framework.utils.set_sleep(0.05)
 
-    def get_jog_mode(self):
-        if self.framework.machine.is_alive:
-            self.api.poll()
-
